/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package javax.management;

import java.io.Serializable;

/**
 * Descriptor is cloneable since represent a snapshot of what the client passed in to the model mbean.
 * This ensures that if the client nulls out some value, the descriptor is still valid, since it has been cloned
 * prior the client modification. The client can always re-set the descriptor on the model mbean.
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.2 $
 */
public interface Descriptor extends Cloneable, Serializable
{
	public Object getFieldValue(String fieldName) throws RuntimeOperationsException;
	public void setField(String fieldName, Object fieldValue) throws RuntimeOperationsException;
	public void removeField(String fieldName);
	public String[] getFieldNames();
	public Object[] getFieldValues(String[] fieldNames);
	public String[] getFields();
	public void setFields(String[] fieldNames, Object[] fieldValues) throws RuntimeOperationsException;
	public Object clone() throws RuntimeOperationsException;
	public boolean isValid() throws RuntimeOperationsException;
}
