/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package javax.management;

import java.lang.reflect.Constructor;

/**
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.3 $
 */
public class MBeanConstructorInfo extends MBeanFeatureInfo
{
	private static final long serialVersionUID = 4433990064191844427L;

	private MBeanParameterInfo[] signature;

	public MBeanConstructorInfo(String description, Constructor constructor)
	{
        super(constructor.getName(), description);
        Class[] params = constructor.getParameterTypes();
		this.signature = new MBeanParameterInfo[params.length];
		for (int i = 0; i < params.length; ++i)
		{
			this.signature[i] = new MBeanParameterInfo("", params[i].getName(), "");
		}
	}

	public MBeanConstructorInfo(String name, String description, MBeanParameterInfo[] signature)
	{
		super(name, description);
		this.signature = signature == null ? new MBeanParameterInfo[0] : signature;
	}

	public MBeanParameterInfo[] getSignature()
	{
		return signature;
	}

	public int hashCode()
	{
		int hash = super.hashCode();

		MBeanParameterInfo[] signature = getSignature();
		for (int i = 0; i < signature.length; ++i)
		{
			MBeanParameterInfo param = signature[i];
			hash ^= param == null ? 0 : param.hashCode();
		}

		return hash;
	}

	public boolean equals(Object obj)
	{
		if (!super.equals(obj)) {return false;}

		try
		{
			MBeanConstructorInfo other = (MBeanConstructorInfo)obj;

			MBeanParameterInfo[] signature = getSignature();
			MBeanParameterInfo[] otherSignature = other.getSignature();
			if (signature.length != otherSignature.length) {return false;}
			for (int i = 0; i < signature.length; ++i)
			{
				MBeanParameterInfo param = signature[i];
				MBeanParameterInfo otherParam = otherSignature[i];
				if (param != null && !param.equals(otherParam)) {return false;}
				if (param == null && otherParam != null) {return false;}
			}
			return true;
		}
		catch (ClassCastException ignored) {}
		return false;
	}
}
