/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package javax.management;

import java.io.Serializable;

/**
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.5 $
 */
public class MBeanInfo implements Cloneable, Serializable
{
	private static final long serialVersionUID = -6451021435135161911L;

	private String className;
	private String description;
	private MBeanConstructorInfo[] constructors;
	private MBeanAttributeInfo[] attributes;
	private MBeanOperationInfo[] operations;
	private MBeanNotificationInfo[] notifications;

	public MBeanInfo(String className,
					 String description,
					 MBeanAttributeInfo[] attributes,
					 MBeanConstructorInfo[] constructors,
					 MBeanOperationInfo[] operations,
					 MBeanNotificationInfo[] notifications)
	{
		this.className = className;
		this.description = description;

		this.constructors = constructors;
		this.attributes = attributes;
		this.operations = operations;
		this.notifications = notifications;
	}

	public Object clone()
	{
		// This class is read only, so no need to clone also data members
		try
		{
			return super.clone();
		}
		catch (CloneNotSupportedException x)
		{
			return null;
		}
	}
	public String getClassName() {return className;}
	public String getDescription() {return description;}
	public MBeanConstructorInfo[] getConstructors() {return constructors;}
	public MBeanAttributeInfo[] getAttributes() {return attributes;}
	public MBeanOperationInfo[] getOperations() {return operations;}
	public MBeanNotificationInfo[] getNotifications() {return notifications;}
}
