/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.adaptor.http;

import mx4j.MBeanDescriptionAdapter;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

/**
 *
 * @author <a href="mailto:tibu@users.sourceforge.net">Carlos Quiroz</a>
 * @version $Revision: 1.3 $
 */
public class HttpAdaptorMBeanDescription extends MBeanDescriptionAdapter
{
	public String getMBeanDescription()
	{
		return "HttpAdaptor MBean";
	}

	public String getConstructorDescription(Constructor ctor)
	{
		// there is only one constructor
		return "Default HttpAdaptor empty constructor";
	}

	public String getAttributeDescription(String attribute)
	{
		if (attribute.equals("Port"))
		{
			return "Server's listening port";
		}
		if (attribute.equals("Host"))
		{
			return "Server's listening host";
		}
		if (attribute.equals("Processor"))
		{
			return "Target processor";
		}
		if (attribute.equals("ProcessorName"))
		{
			return "Target processor MBean's name";
		}
		if (attribute.equals("Active"))
		{
			return "True if the HttpAdapter is running";

		}
		if (attribute.equals("AuthenticationMethod"))
		{
			return "Indicates which authentication method to use, valid values are (none/basic/digest)";
		}
		return super.getAttributeDescription(attribute);
	}

	public String getOperationDescription(Method operation)
	{
		if (operation.getName().equals("start"))
		{
			return "Starts the server operation";
		}
		if (operation.getName().equals("stop"))
		{
			return "Stops the server operation";
		}
		if (operation.getName().equals("restart"))
		{
			return "Restarts the server operation";
		}
		if (operation.getName().equals("addAuthorization"))
		{
			return "Adds a username/password which are valid for logging into the server";
		}
		return super.getOperationDescription(operation);
	}

	public String getOperationParameterName(Method method, int index)
	{
		if (method.getName().equals("addAuthorization"))
		{
			switch (index)
			{
				case 0:
					return "username";
				case 1:
					return "password";
			}
		}
		return super.getOperationParameterName(method, index);
	}

	public String getOperationParameterDescription(Method method, int index)
	{
		if (method.getName().equals("addAuthorization"))
		{
			switch (index)
			{
				case 0:
					return "Authorized username";
				case 1:
					return "Authorized password";
			}
		}
		return super.getOperationParameterDescription(method, index);
	}

}
