/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */
package mx4j.adaptor.http;

import javax.management.MBeanServer;
import javax.management.ObjectInstance;
import javax.management.ObjectName;
import javax.management.JMException;
import java.io.IOException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import java.util.Iterator;
import java.util.List;
import java.util.ArrayList;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Text;
import javax.xml.parsers.DocumentBuilder;

/**
 * ServerCommandProcessor, processes a request for getting all the
 * MBeans of the current server
 *
 * @author <a href="mailto:tibu@users.sourceforge.net">Carlos Quiroz</a>
 * @version $Revision: 1.2 $
 */
class ServerCommandProcessor implements HttpCommandProcessor
{
	private MBeanServer server;

	private DocumentBuilder builder;

	public ServerCommandProcessor(MBeanServer server, DocumentBuilder builder)
	{
		this.server = server;
		this.builder = builder;
	}

	public Document executeRequest(HttpInputStream in) throws IOException, JMException
	{
		Document document = builder.newDocument();

		Element root = document.createElement("Server");
		document.appendChild(root);

		String classVariable = in.getVariable("instanceof");

		Set mbeans = server.queryMBeans(null, null);
		Iterator i = mbeans.iterator();
		while (i.hasNext())
		{
			ObjectInstance instance = (ObjectInstance)i.next();
			if (classVariable != null && !classVariable.equals(instance.getClassName()))
			{
				continue;
			}
			Element mBeanElement = document.createElement("MBean");
			mBeanElement.setAttribute("name", instance.getObjectName().toString());
			root.appendChild(mBeanElement);
		}
		return document;
	}

}
