/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */
package mx4j.adaptor.http;


import java.io.IOException;
import org.w3c.dom.Document;

/**
 * Management interface of the XSLTPostProcessor
 *
 * @author <a href="mailto:tibu@users.sourceforge.net">Carlos Quiroz</a>
 * @version $Revision: 1.2 $
 */
public interface XSLTProcessorMBean extends ProcessorMBean
{
	/**
	 * Sets the root file of the transformation files. The XSLT processor
	 * requires to know where the XSLT and other files are. If the path points
	 * to a .jar or .zip file, then the files are directly loaded from it. If
	 * not the files are loaded directly from file. If null the files carried
	 * on the same class' jar are used.
	 *
	 * If you use a .jar or .zip set also the root path
	 */
	public void setFile(String file);

	/**
	 * Returns the file or dir containing the transformation files
	 */
	public String getFile();

	/**
	 * If you are using a .jar or .zip file, you may use the root path
	 * indicating the location of the files in the jar.
	 */
	public void setPathInJar(String path);

	/**
	 * Returns the path of the files in the jar file.
	 */
	public String getPathInJar();

	/**
	 * Indicates whether the xsl files are read form a jar file
	 */
	public boolean isUseJar();

	/**
	 * Indicates whether the xsl files are read form a dir in the filesystem
	 */
	public boolean isUsePath();

	/**
	 * Use cache. If set the XSLT transformation are cached. This is true by
	 * default but you may want to set it to false for development
	 */
	public void setUseCache(boolean useCache);

	public boolean isUseCache();

	/**
	 * Adds a mime type if the defaults one are not enough. Use as
	 * <code>
	 *  addMimeType(".gif", "image/gif");
	 * </code>
	 */
	public void addMimeType(String extension, String type);


}
