/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.adaptor.http;

import mx4j.MBeanDescriptionAdapter;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

/**
 *
 * @author <a href="mailto:tibu@users.sourceforge.net">Carlos Quiroz</a>
 * @version $Revision: 1.3 $
 */
public class XSLTProcessorMBeanDescription extends MBeanDescriptionAdapter
{
	public String getMBeanDescription()
	{
		return "XSLT Processor MBean";
	}

	public String getConstructorDescription(Constructor ctor)
	{
		// there is only one constructor
		return "Default XSLTProcessor empty constructor";
	}

	public String getAttributeDescription(String attribute)
	{
		if (attribute.equals("UseCache"))
		{
			return "Indicates whether to cache the XSL templates objects, speeding up the display";
		}
		if (attribute.equals("File"))
		{
			return "Root of the xsl files collection";
		}
		if (attribute.equals("PathInJar"))
		{
			return "Root path inside a jar or zip file";
		}
		if (attribute.equals("UseJar"))
		{
			return "True if xsl files are read in a .jar/.zip file";
		}
		if (attribute.equals("UsePath"))
		{
			return "True if xsl files are read from a dir";
		}
		return super.getAttributeDescription(attribute);
	}

	public String getOperationDescription(Method operation)
	{
		if (operation.getName().equals("addMimeType"))
		{
			return "Adds an extra MIME type. Use as addMimeType(\"*.css\", \"text/css\")";
		}
		return null;
	}

	public String getOperationParameterName(Method method, int index)
	{
		if (method.getName().equals("addMimeType"))
		{
			switch (index) {
				case 0:
					return "extension";
				case 1:
					return "MIME type";
			}
		}
		return "param" + (index + 1);
	}

	public String getOperationParameterDescription(Method method, int index)
	{
		if (method.getName().equals("addMimeType"))
		{
			switch (index) {
				case 0:
					return "Extension name, as .xxx";
				case 1:
					return "MIME type like text/css";
			}
		}
		return "Operation's parameter n. " + (index + 1);
	}
}
