/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.adaptor.interceptor;

import java.io.Serializable;

/**
 * The invocation information carrier.
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.3 $
 */
public class Invocation implements Serializable
{
	private String m_methodName;
	private String[] m_signature;
	private Object[] m_arguments;
	private InvocationContext m_context;

	/**
	 * Sets the method name to be invoked on the server-side
	 * @see #setSignature
	 */
	public void setMethodName(String name)
	{
		m_methodName = name;
	}

	/**
	 * Sets the signature of the method to be invoked on the server-side
	 * @see #setArguments
	 */
	public void setSignature(String[] signature)
	{
		m_signature = signature;
	}

	/**
	 * Sets the arguments of the method to be invoked on the server-side
	 * @see #setMethodName
	 */
	public void setArguments(Object[] args)
	{
		if (args == null) {args = new Object[0];}
		m_arguments = args;
	}

	/**
	 * Sets the invocation user-defined information
	 * @see #getInvocationContext
	 */
	public void setInvocationContext(InvocationContext context)
	{
		m_context = context;
	}

	/**
	 * Returns the invocation user-defined information
	 * @see #setInvocationContext
	 */
	public InvocationContext getInvocationContext()
	{
		return m_context;
	}

	/**
	 * Returns the invocation method name
	 */
	public String getMethodName()
	{
		return m_methodName;
	}

	/**
	 * Returns the invocation method arguments
	 */
	public Object[] getArguments()
	{
		return m_arguments;
	}

	/**
	 * Returns the invocation method signature
	 */
	public String[] getSignature()
	{
		return m_signature;
	}
}
