/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.adaptor.rmi.iiop;

import java.rmi.NoSuchObjectException;
import java.rmi.RemoteException;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import mx4j.adaptor.rmi.RMIAdaptor;
import mx4j.adaptor.rmi.RMIProtocolAdaptorImpl;

/**
 * Adaptor for the IIOP protocol, the CORBA default protocol
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.3 $
 */
public class IIOPAdaptor extends RMIAdaptor implements IIOPAdaptorMBean
{
	private RMIProtocolAdaptorImpl m_adaptor;
	private boolean m_running;

	public void start() throws RemoteException, NamingException
	{
		if (!isRunning())
		{
			m_adaptor = new RMIProtocolAdaptorImpl(getMBeanServer(), getObjectName(), getInterceptors());

			PortableRemoteObject.exportObject(m_adaptor);

			String jndiName = findJNDIName();
			setJNDIName(jndiName);

			bind(m_adaptor);

			m_running = true;
		}
	}

	public void stop() throws NoSuchObjectException, NamingException
	{
		if (isRunning())
		{
			PortableRemoteObject.unexportObject(m_adaptor);

			unbind();

			m_adaptor.unregisterInterceptors();

			m_running = false;
		}
	}

	public boolean isRunning()
	{
		return m_running;
	}

	protected ObjectName getDefaultObjectName() throws MalformedObjectNameException
	{
		return new ObjectName(OBJECT_NAME);
	}

	private String findJNDIName() throws RemoteException
	{
		String jndi = getJNDIName();
		if (jndi == null || jndi.trim().length() == 0)
		{
			// User did not provided one, return a default one
			StringBuffer buffer = new StringBuffer("jmx-adaptor:iiop:");
			buffer.append(getHostName());
			return buffer.toString();
		}
		else
		{
			return jndi;
		}
	}
}
