/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.adaptor.rmi.jrmp;

import java.rmi.NoSuchObjectException;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

import javax.management.JMException;
import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;
import javax.naming.NamingException;

import mx4j.adaptor.rmi.RMIAdaptor;
import mx4j.adaptor.rmi.RMIProtocolAdaptorImpl;
import mx4j.adaptor.rmi.SSLAdaptorRMIServerSocketFactory;
import mx4j.adaptor.rmi.SSLRMIClientSocketFactory;

/**
 * Adaptor for the JRMP protocol, the native protocol of Java RMI.
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.3 $
 */
public class JRMPAdaptor extends RMIAdaptor implements JRMPAdaptorMBean
{
	private RMIProtocolAdaptorImpl m_adaptor;
	private boolean m_running;
	private int m_port;
	private String m_sslFactory;

	public void start() throws RemoteException, NamingException, JMException
	{
		if (!isRunning())
		{
			m_adaptor = new RMIProtocolAdaptorImpl(getMBeanServer(), getObjectName(), getInterceptors());

			if (isSSL())
			{
				ObjectName factory = new ObjectName(getSSLFactory());
				UnicastRemoteObject.exportObject(m_adaptor, getPort(), new SSLRMIClientSocketFactory(), new SSLAdaptorRMIServerSocketFactory(getMBeanServer(), factory));
			}
			else
			{
				UnicastRemoteObject.exportObject(m_adaptor, getPort());
			}

			String jndiName = findJNDIName();
			setJNDIName(jndiName);

			bind(m_adaptor);

			m_running = true;
		}
	}

	public void stop() throws NoSuchObjectException, NamingException
	{
		if (isRunning())
		{
			UnicastRemoteObject.unexportObject(m_adaptor, true);

			unbind();

			m_adaptor.unregisterInterceptors();

			m_running = false;
		}
	}

	public boolean isRunning()
	{
		return m_running;
	}

	public int getPort()
	{
		return m_port;
	}

	public void setPort(int port)
	{
		if (!isRunning())
		{
			m_port = port;
		}
		else
		{
			throw new IllegalStateException("Cannot perform this operation while running");
		}
	}

	public String getSSLFactory()
	{
		return m_sslFactory;
	}

	public void setSSLFactory(String factory)
	{
		if (!isRunning())
		{
			m_sslFactory = factory;
		}
		else
		{
			throw new IllegalStateException("Cannot perform this operation while running");
		}
	}

	private boolean isSSL()
	{
		return getSSLFactory() != null;
	}

	protected ObjectName getDefaultObjectName() throws MalformedObjectNameException
	{
		return new ObjectName(OBJECT_NAME);
	}

	private String findJNDIName()
	{
		String jndi = getJNDIName();
		if (jndi == null || jndi.trim().length() == 0)
		{
			// User did not provided one, return a default one
			StringBuffer buffer = new StringBuffer("jmx-adaptor:jrmp:");
			buffer.append(getHostName()).append(":");
			buffer.append(getPort());
			return buffer.toString();
		}
		else
		{
			return jndi;
		}
	}
}
