/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.server.interceptor;

import java.util.HashMap;

import javax.management.ReflectionException;
import javax.management.MBeanException;
import javax.management.MBeanRegistrationException;
import javax.management.MBeanInfo;
import javax.management.AttributeList;
import javax.management.AttributeNotFoundException;
import javax.management.Attribute;
import javax.management.InvalidAttributeValueException;
import javax.management.NotificationListener;
import javax.management.NotificationFilter;
import javax.management.ListenerNotFoundException;
import javax.management.Notification;
import javax.management.ObjectName;

import mx4j.server.MBeanMetaData;

/**
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.2 $
 */
public class NotificationListenerMBeanServerInterceptor extends DefaultMBeanServerInterceptor
{
	private HashMap m_listeners = new HashMap();

	private static class ListenerWrapper implements NotificationListener
	{
		private NotificationListener m_listener;
		private ObjectName m_objectName;

		private ListenerWrapper(NotificationListener listener, ObjectName name)
		{
			m_listener = listener;
			m_objectName = name;
		}

		public void handleNotification(Notification notification, Object handback)
		{
			Object source = notification.getSource();
			try
			{
				// Change the source to be the ObjectName of the notification broadcaster
				notification.setSource(m_objectName);
				// Notify the real listener
				m_listener.handleNotification(notification, handback);
			}
			finally
			{
				notification.setSource(source);
			}
		}
	}

	public String getType()
	{
		return "notificationlistener";
	}

	public void addNotificationListener(MBeanMetaData metadata, NotificationListener listener, NotificationFilter filter, Object handback)
	{
		if (!isEnabled()) {super.addNotificationListener(metadata, listener, filter, handback);}

		// Replace the real listener with our wrapper
		ListenerWrapper wrapper = listener == null ? null : new ListenerWrapper(listener, metadata.name);
		super.addNotificationListener(metadata, wrapper, filter, handback);

		synchronized (m_listeners)
		{
			m_listeners.put(listener, wrapper);
		}
	}

	public void removeNotificationListener(MBeanMetaData metadata, NotificationListener listener, NotificationFilter filter, Object handback) throws ListenerNotFoundException
	{
		if (!isEnabled()) {super.removeNotificationListener(metadata, listener, filter, handback);}

		synchronized (m_listeners)
		{
			ListenerWrapper wrapper = (ListenerWrapper)m_listeners.get(listener);
			if (wrapper == null) {throw new ListenerNotFoundException("Listener not found: " + listener);}

			super.removeNotificationListener(metadata, wrapper, filter, handback);

			m_listeners.remove(listener);
		}
	}
}
