/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.tools.naming;

import java.net.URL;
import java.net.URLClassLoader;
import java.net.MalformedURLException;
import java.rmi.registry.Registry;
import java.rmi.Remote;
import java.rmi.NoSuchObjectException;
import java.rmi.RemoteException;
import java.util.List;
import java.util.Arrays;
import java.lang.reflect.Method;
import java.lang.reflect.InvocationTargetException;

import javax.management.MBeanRegistration;
import javax.management.ObjectName;
import javax.management.MBeanServer;

/**
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.2 $
 */
public class NamingService implements NamingServiceMBean, MBeanRegistration
{
	private int m_port;
	private Remote m_registry;
	private boolean m_running;

	public NamingService()
	{
		this(Registry.REGISTRY_PORT);
	}

	public NamingService(int port)
	{
		m_port = port;
	}

	public ObjectName preRegister(MBeanServer server, ObjectName name) throws Exception
	{
		return name == null ? new ObjectName(OBJECT_NAME) : name;
	}

	public void postRegister(Boolean registrationDone)
	{
	}

	public void preDeregister() throws Exception
	{
		stop();
	}

	public void postDeregister()
	{
	}

	public void setPort(int port)
	{
		m_port = port;
	}

	public int getPort()
	{
		return m_port;
	}

	public boolean isRunning()
	{
		return m_running;
	}

	public void start() throws RemoteException
	{
		if (!isRunning())
		{
			m_registry = java.rmi.registry.LocateRegistry.createRegistry(getPort());
			m_running = true;
		}
	}

	public void stop() throws NoSuchObjectException
	{
		if (isRunning())
		{
			java.rmi.server.UnicastRemoteObject.unexportObject(m_registry, false);
			m_running = false;
		}
	}
}
