/*
 * Copyright (C) MX4J.
 * All rights reserved.
 *
 * This software is distributed under the terms of the MX4J License version 1.0.
 * See the terms of the MX4J License in the documentation provided with this software.
 */

package mx4j.tools.naming;

import java.net.URL;
import java.net.MalformedURLException;
import java.rmi.RemoteException;
import java.rmi.NoSuchObjectException;

/**
 * Management interface for the Naming MBean
 *
 * @author <a href="mailto:biorn_steedom@users.sourceforge.net">Simone Bordet</a>
 * @version $Revision: 1.2 $
 */
public interface NamingServiceMBean
{
	/**
	 * The default object name for this MBean
	 */
	public static final String OBJECT_NAME = "Naming:type=registry";

	/**
	 * Returns the port on which the rmiregistry is running
	 */
	public int getPort();
	/**
	 * Sets the port on which the rmiregistry will run.
	 */
	public void setPort(int port);
	/**
	 * Starts the rmiregistry, that now can accept incoming calls
	 * @see #stop
	 */
	public void start() throws RemoteException;
	/**
	 * Stops the rmiregistry, that now cannot accept anymore incoming calls
	 * @see #start
	 */
	public void stop() throws NoSuchObjectException;
	/**
	 * Returns whether this MBean has been started and not yet stopped.
	 * @see #start
	 */
	public boolean isRunning();
}
